# wedne: координируем строительство башни

_This project was built for a Russian-speaking community. There's no English version of
README._

В vas3k.club чатах любят строить башни. Башни --- это однобуквенные сообщения от
участников, из которых может составиться слово. Самый важный башенный день --- среда. В
среду принято строить "ITSWEDNESDAYMYDUDES" и отправлять лягушек. Это непросто: постоянно
кто-то хочет отправить сообщение между буквами. Клубчанин не может быть посередине,
приходится выбирать между созиданием и разрушением.

wedne состоит из двух частей: `wedne.server` и `wedne.client`. Клиенты регистрируются в
общем сервере и получают команды: отправить такую-то букву в такое-то время.

## Инструкции

### Как строить башни?

Не обязательно быть программистом. Прочтите эту секцию и узнайте, как поучаствовать в
строительстве.

1. Скачайте на компьютер [установщик Python](py),
2. Пройдите установку (если спросят, отметьте "Add python.exe to PATH"),
3. Откройте приложение "Терминал" или "Командную строку",
4. Введите туда `python -m pip install wedne` --- теперь вы установили wedne,
5. Наконец введите `python -m wedne.client` и залогиньтесь как в телеграме.

Теперь у вас работает клиент. Он подключится к серверу и начнет ждать команду. Когда
придет время, в чат от вашего имени отправится буква.

Можете закрывать инструкцию.

### Я продвинутый, могу ли я запустить через Docker?

```sh
docker run qwskr/wedne:latest
```

### Я продвинутый, могу ли я запустить сервер?

Проще всего склонировать и запустить с помощью Docker Compose:

```sh
docker compose up
```



[py]: https://www.python.org/downloads/
